@@ -28,6 +28,7 @@
 #include "panel-util.h"
 #include "session.h"
 #include "xstuff.h"
+#include "panel-stock-icons.h"
 
 extern GlobalConfig global_config;
 extern gboolean commie_mode;
@@ -275,41 +276,84 @@ key_press_drawer (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	PanelWidget *parent;
 	GtkWidget *drawer_panel;
 	GtkDirectionType dir;
+	GtkOrientation orient;
 
 	if (event->state != gtk_accelerator_get_default_mod_mask ()) {
 		drawer = data;
 		parent = PANEL_WIDGET (drawer->button->parent);
 		drawerw = DRAWER_WIDGET (drawer->drawer);
 
+		orient = parent->orient;
+
 		switch (event->keyval) {
 		case GDK_Up:
 		case GDK_KP_Up:
+			if (orient == GTK_ORIENTATION_HORIZONTAL) {
+				switch (BASEP_WIDGET (drawerw)->state) {
+				case BASEP_SHOWN:
+				case BASEP_AUTO_HIDDEN:
+					dir = GTK_DIR_TAB_BACKWARD;
+					break;
+				default:
+                               		return TRUE;
+					break;
+				}
+			} else  /* orient == GTK_ORIENTATION_VERTICAL */ {
+				/* let default focus movement happen */
+				return FALSE;
+			}
+			break;
 		case GDK_Left:
 		case GDK_KP_Left:
-			switch (BASEP_WIDGET (drawerw)->state) {
-			case BASEP_SHOWN:
-			case BASEP_AUTO_HIDDEN:
-				dir = GTK_DIR_TAB_BACKWARD;
-				break;
-			default:
-                                return TRUE;
-				break;
+			if (orient == GTK_ORIENTATION_VERTICAL) {
+				switch (BASEP_WIDGET (drawerw)->state) {
+				case BASEP_SHOWN:
+				case BASEP_AUTO_HIDDEN:
+					dir = GTK_DIR_TAB_BACKWARD;
+					break;
+				default:
+                               		return TRUE;
+					break;
+				}
+			} else  /* orient == GTK_ORIENTATION_HORIZONTAL */ {
+				/* let default focus movement happen */
+				return FALSE;
 			}
 			break;
 		case GDK_Down:
 		case GDK_KP_Down:
+			if (orient == GTK_ORIENTATION_HORIZONTAL) {
+				switch (BASEP_WIDGET (drawerw)->state) {
+				case BASEP_SHOWN:
+				case BASEP_AUTO_HIDDEN:
+					dir = GTK_DIR_TAB_FORWARD;
+					break;
+				default:
+                               		return TRUE;
+					break;
+				}
+			} else  /* orient == GTK_ORIENTATION_VERTICAL */ {
+				/* let default focus movement happen */
+				return FALSE;
+			}
+			break;
 		case GDK_Right:
 		case GDK_KP_Right:
-			switch (BASEP_WIDGET (drawerw)->state) {
-			case BASEP_SHOWN:
-			case BASEP_AUTO_HIDDEN:
-				dir = GTK_DIR_TAB_FORWARD;
-				break;
-			default:
-                                return TRUE;
-				break;
+			if (orient == GTK_ORIENTATION_VERTICAL) {
+				switch (BASEP_WIDGET (drawerw)->state) {
+				case BASEP_SHOWN:
+				case BASEP_AUTO_HIDDEN:
+					dir = GTK_DIR_TAB_FORWARD;
+					break;
+				default:
+                               		return TRUE;
+					break;
+				}
+			} else  /* orient == GTK_ORIENTATION_HORIZONTAL */ {
+				/* let default focus movement happen */
+				return FALSE;
 			}
-                        break;
+			break;
 		case GDK_Escape:
 			switch (BASEP_WIDGET (drawerw)->state) {
 			case BASEP_SHOWN:
@@ -544,19 +588,23 @@ create_drawer_applet (GtkWidget   *drawer_panel,
 	
 	drawer->properties = NULL;
 
+	drawer->focus_out_handler = 0;
+
 	if (string_empty (tooltip))
 		drawer->tooltip = NULL;
 	else
 		drawer->tooltip = g_strdup (tooltip);
 
 	if (string_empty (pixmap)) {
-		drawer->pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-							    "panel-drawer.png", TRUE, NULL);
+		drawer->pixmap = NULL;
+		drawer->button = button_widget_new_from_stock (PANEL_STOCK_DRAWER, -1,
+							       TRUE, orient);
 	} else {
 		drawer->pixmap = g_strdup (pixmap);
+		drawer->button = button_widget_new (drawer->pixmap, -1,
+						    TRUE, orient);
 	}
-	drawer->button = button_widget_new (drawer->pixmap, -1,
-					    TRUE, orient);
+	
 	if (!drawer->button) {
 		free_drawer (drawer);
 		return NULL;
@@ -599,8 +647,13 @@ create_drawer_applet (GtkWidget   *drawer_panel,
 			    G_CALLBACK (destroy_drawer), drawer);
 	g_signal_connect (G_OBJECT (drawer->button), "focus_in_event",
 			    G_CALLBACK (focus_in_drawer), drawer);
-	g_signal_connect (G_OBJECT (drawer->button), "focus_out_event",
-			    G_CALLBACK (focus_out_drawer), drawer);
+
+	drawer->focus_out_handler = g_signal_connect (
+						G_OBJECT (drawer->button), 
+						"focus_out_event",
+						G_CALLBACK (focus_out_drawer), 
+						drawer);
+
 	g_signal_connect (G_OBJECT (drawer->button), "key_press_event",
 			    G_CALLBACK (key_press_drawer), drawer);
 	g_signal_connect (G_OBJECT (drawer->drawer), "key_press_event",
