@@ -46,7 +46,7 @@ struct _FloatingPosClass {
 
 GType floating_pos_get_type (void) G_GNUC_CONST;
 
-GtkWidget *floating_widget_new (gchar *panel_id,
+GtkWidget *floating_widget_new (const char *panel_id,
 				int screen,
 				int monitor,
 				gint16 x,
@@ -57,8 +57,8 @@ GtkWidget *floating_widget_new (gchar *panel_id,
 				int sz,
 				gboolean hidebuttons_enabled,
 				gboolean hidebutton_pixmap_enabled,
-				PanelBackType back_type,
-				char *back_pixmap,
+				PanelBackgroundType back_type,
+				const char *back_pixmap,
 				gboolean fit_pixmap_bg,
 				gboolean stretch_pixmap_bg,
 				gboolean rotate_pixmap_bg,
@@ -75,8 +75,8 @@ void floating_widget_change_params (FloatingWidget *floating,
 				    int sz,
 				    gboolean hidebuttons_enabled,
 				    gboolean hidebutton_pixmap_enabled,
-				    PanelBackType back_type,
-				    char *back_pixmap,
+				    PanelBackgroundType back_type,
+				    const char *back_pixmap,
 				    gboolean fit_pixmap_bg,
 				    gboolean stretch_pixmap_bg,
 				    gboolean rotate_pixmap_bg,
