@@ -8,9 +8,9 @@
 
 #include <gdk/gdktypes.h>
 
-void		panel_global_keys_setup		(void);
-GdkFilterReturn	panel_global_keys_filter	(GdkXEvent *gdk_xevent,
-						 GdkEvent *event,
-						 gpointer data);
+void		panel_global_keys_setup	 (void);
+GdkFilterReturn	panel_global_keys_filter (GdkXEvent *gdk_xevent,
+					  GdkEvent  *event,
+				          GdkScreen *screen);
 
 #endif
